==> macsyfinder_2.0~rc1.orig.tar.gz: macsyfinder-2.0rc1/CONTRIBUTORS.md <==
CONTRIBUTORS
============

This is a list of people who have made contributions to Macsyfinder.


| Emoji             | Represents    | Comments                                                             |
|-------------------|---------------|----------------------------------------------------------------------|
|:computer:         | Code          | Linked to whoever commits on source code by the user on this project |
|:pencil2:          | Documentation | Linked to whoever commits on Wiki, or other source of documenta      |
|:white_check_mark: | Tests         | Linked to whoever commits on unit or functional tests                |
|:bulb:             | Ideas         | Linked to whoever brings ideas                                       |
|:file_folder:      | Data          | Linked to whoever contributed data  (both tests and datasets)        |
|:bug:              | Bug reports   | Linked to whoever report issues                                      |
|:umbrella:         | User Testing  | Linked to whoever does, user tests                                   |


* Sophie Abby <sophie.abby@univ-grenoble-alpes.fr> <https://www-timc.imag.fr/en/sophie-abby> :bulb: :computer: :pencil2: :file_folder: :umbrella: :bug:
* Eduardo Rocha <https://research.pasteur.fr/en/member/eduardo-rocha/> :bulb: :umbrella:
* Bertrand Néron <https://github.com/bneron/> :computer: :bulb: :pencil2: :white_check_mark: 
* freeh4cker <https://github.com/freeh4cker> :computer:
* Hervé Ménager <https://github.com/hmenager> :computer:
* Francisco J. Ossandon <https://github.com/fjossandon> :computer:
* Rémi Denise <https://scholar.google.com/citations?user=hAhbGqkAAAAJ&hl=en> :bulb: :file_folder: :umbrella:
* Marie Touchon <https://research.pasteur.fr/en/member/marie-touchon/> :bulb: :umbrella:
* Amandine Perrin <https://github.com/orgs/gem-pasteur/people/asetGem> :computer:
* Yoann Dufresne <https://research.pasteur.fr/en/member/yoann-dufresne/> :bulb:

==> macsyfinder_2.1.4.orig.tar.gz: macsyfinder-2.1.4/CONTRIBUTORS.md <==
CONTRIBUTORS
============

This is a list of people who have made contributions to Macsyfinder.


| Emoji             | Represents    | Comments                                                             |
|-------------------|---------------|----------------------------------------------------------------------|
|:computer:         | Code          | Linked to whoever commits on source code by the user on this project |
|:pencil2:          | Documentation | Linked to whoever commits on Wiki, or other source of documenta      |
|:white_check_mark: | Tests         | Linked to whoever commits on unit or functional tests                |
|:bulb:             | Ideas         | Linked to whoever brings ideas                                       |
|:file_folder:      | Data          | Linked to whoever contributed data  (both tests and datasets)        |
|:bug:              | Bug reports   | Linked to whoever report issues                                      |
|:umbrella:         | User Testing  | Linked to whoever does, user tests                                   |


* Sophie Abby <sophie.abby@univ-grenoble-alpes.fr> <https://www-timc.imag.fr/en/sophie-abby> :bulb: :computer: :pencil2: :file_folder: :umbrella: :bug:
* Eduardo Rocha <https://research.pasteur.fr/en/member/eduardo-rocha/> :bulb: :umbrella:
* Bertrand Néron <https://github.com/bneron/> :computer: :bulb: :pencil2: :white_check_mark:
* freeh4cker <https://github.com/freeh4cker> :computer:
* Hervé Ménager <https://github.com/hmenager> :computer:
* Francisco J. Ossandon <https://github.com/fjossandon> :computer:
* Rémi Denise <https://scholar.google.com/citations?user=hAhbGqkAAAAJ&hl=en> :bulb: :file_folder: :umbrella:
* Marie Touchon <https://research.pasteur.fr/en/member/marie-touchon/> :bulb: :umbrella:
* Amandine Perrin <https://github.com/orgs/gem-pasteur/people/asetGem> :computer:
* Yoann Dufresne <https://research.pasteur.fr/en/member/yoann-dufresne/> :bulb:



* Ezra Herman <https://github.com/ezherman> :bug:
* Nelle Varoquaux <https://github.com/NelleV> :bug:
* Nicolas CELLIER <https://github.com/celliern> :bug:
* Nilesh Patra <https://github.com/nileshpatra> :bug: :computer:
* Antônio Camargo <https://github.com/apcamargo> :bug:
* TrellixVulnTeam <https://github.com/TrellixVulnTeam> :computer:
